@@ -1,23 +1,19 @@
 package Text::NLP::Stanford::EntityExtract;
+$Text::NLP::Stanford::EntityExtract::VERSION = '0.07';
 
 use warnings;
 use strict;
 
-use Mouse;
+use Moo;
 use utf8;
 use Text::Unidecode;
 use IO::Socket;
+use Data::Dumper qw(Dumper);
 
 =head1 NAME
 
 Text::NLP::Stanford::EntityExtract - Talks to a stanford-ner socket server to get named entities back
 
-=head1 VERSION
-
-Version 0.06
-
-=cut
-
 =head1 Quick Start:
 
 =over
@@ -50,10 +46,6 @@ Wrte a script to extract the named entities from the text, like the following:
 
 =back
 
-=cut
-
-our $VERSION = '0.06';
-
 =head2 METHODS
 
 =head2 new ( host => '127.0.0.1', port => '1234' debug => 0|1|2);
@@ -63,9 +55,9 @@ to 1 and shows the actual text as well as the length if set to > 1.
 
 =cut
 
-has 'host'  => (is => 'ro', isa => 'Str', default => '127.0.0.1');
-has 'port'  => (is => 'ro', isa => 'Int', default => '1234');
-has 'debug' => (is => 'rw', isa => 'Int', default => 0);
+has 'host'  => (is => 'ro',  default => '127.0.0.1');
+has 'port'  => (is => 'ro',  default => '1234');
+has 'debug' => (is => 'rw',  default => 0);
 
 =head2 server
 
@@ -98,9 +90,11 @@ sub get_entities {
      foreach my $t (@txt) {
          warn "LENGTH: " . length($t) .  "\n" if $self->debug > 0;
          warn "TEXT: " .  $t . "\n" if $self->debug > 1;
-         $t = unidecode($t);
+
+         #$t = unidecode($t);
+         utf8::decode($t);
          $t =~ s/\n/ /mg;
-         $t =~ s/[^[:ascii:]]//mg;
+         #$t =~ s/[^[:ascii:]]//mg;
          push @result, $self->_process_line($t);
      }
     return @result;
@@ -116,9 +110,10 @@ processes a single line of text to tagged text
 sub _process_line {
     my ($self, $line) = @_;
     my $server = $self->server;
+    utf8::encode($line);
     print $server $line,"\n";
-    my $tagged_txt =  <$server>;
-    return $tagged_txt;
+    my @tagged_txt =  <$server>;
+    return \@tagged_txt;
 }
 
 =head2 entities_list($tagged_line)
@@ -133,23 +128,25 @@ TODO:  This needs some utility subs around it to make it more useful.
 =cut
 
 sub entities_list {
-    my ($self, $line) = @_;
-    my @tagged_words = split /\s+/, $line;
-    my $last_tag = '';
+    my ($self, $lines) = @_;
     my $taglist = {};
-    my $pos = 1;
-    foreach my $w (@tagged_words) {
-        my ($word, $tag) = $w =~ m{(.*)/(.*)$};
-        if (! $taglist->{$tag}) {
-            $taglist->{$tag} = [ ];
-        }
-        if ($tag ne $last_tag) {
-            push @{$taglist->{$tag}}, [$word, $pos++];
-        }
-        else {
-            push @{ $taglist->{$tag}->[ $#{ $taglist->{$tag}} ] }, [$word, $pos++];
-        }
-        $last_tag = $tag;
+    foreach my $line (@$lines) { 
+      my @tagged_words = split /\s+/, $line;
+      my $last_tag = '';
+      my $pos = 1;
+      foreach my $w (@tagged_words) {
+          my ($word, $tag) = $w =~ m{(.*)/(.*)$};
+          if (! $taglist->{$tag}) {
+              $taglist->{$tag} = [ ];
+          }
+          if ($tag ne $last_tag) {
+              push @{$taglist->{$tag}}, [$word, $pos++];
+          }
+          else {
+              push @{ $taglist->{$tag}->[ $#{ $taglist->{$tag}} ] }, [$word, $pos++];
+          }
+          $last_tag = $tag;
+      }
     }
     return $taglist;
 }
